import styled from "@emotion/styled";
import { faAngleDown, faAngleUp, faBug, faGlobe, } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import React, { useState } from "react";
import { Link } from "../Link/Link";
export const BottomPanel = ({ tabs, height, }) => {
    const [currentTabKey, setCurrentTabKey] = useState("props");
    const [visible, setVisible] = useState(true);
    const currentTab = tabs.find((tab) => tab.key === currentTabKey);
    return (React.createElement(Container, null,
        React.createElement(TabsContainer, null,
            tabs.length > 0 && (React.createElement(ToggleButton, { onClick: () => setVisible(!visible) },
                React.createElement(FontAwesomeIcon, { icon: visible ? faAngleDown : faAngleUp }))),
            tabs.map((tab) => (React.createElement(Tab, { selected: visible && tab.key === currentTabKey, key: tab.key, onClick: () => {
                    setVisible(true);
                    setCurrentTabKey(tab.key);
                }, className: "panel-tab" },
                tab.label,
                tab.notificationCount > 0 && (React.createElement(TabNotificationBubble, null, tab.notificationCount))))),
            React.createElement(Spacer, null),
            React.createElement(OpenBrowser, { href: "https://github.com/zenclabs/reactpreview/issues", target: "_blank", title: "Report an issue" },
                React.createElement(FontAwesomeIcon, { icon: faBug, color: "hsl(0, 80%, 50%)" })),
            React.createElement(OpenBrowser, { href: document.location.href, target: "_blank", title: "Open in browser" },
                React.createElement(FontAwesomeIcon, { icon: faGlobe, color: "hsl(213, 80%, 50%)" }))),
        visible && currentTab && (React.createElement(Panel, { "$height": height }, currentTab && currentTab.panel))));
};
const Container = styled.div `
  background: #fff;
  font-size: 12px;
  z-index: 100;
`;
const DefaultTabColor = "#fff";
const SelectedTabColor = "#E5E9EF";
const TabsContainer = styled.div `
  display: flex;
  flex-direction: row;
  border-left: 1px solid ${DefaultTabColor};
  border-radius: 8px 8px 0 0;
  margin-bottom: -1px;
`;
const Tab = styled.button `
  padding: 8px;
  cursor: pointer;
  border-style: solid;
  border-color: ${DefaultTabColor};
  border-width: 1px 1px 0 0;
  border-radius: 8px 8px 0 0;
  background: ${({ selected }) => selected ? SelectedTabColor : DefaultTabColor};
  outline: none;
  font-size: 0.8rem;
  white-space: nowrap;
  overflow: hidden;
  text-overflow: ellipsis;
`;
const TabNotificationBubble = styled.span `
  margin: 0 4px;
  display: inline-flex;
  align-items: center;
  justify-content: center;
  width: 20px;
  height: 20px;
  border-radius: 10px;
  font-size: 12px;
  background: hsl(0, 73%, 50%);
  color: #fff;
`;
const Spacer = styled.span `
  flex-grow: 1;
`;
const OpenBrowser = styled(Link) `
  padding: 8px;
  font-weight: bold;
  text-decoration: none;
  margin-left: 8px;

  &:hover {
    color: hsl(213, 100%, 36%);
  }
`;
const ToggleButton = styled.button `
  border: none;
  outline: none;
  display: flex;
  flex-direction: row;
  justify-content: center;
  align-items: center;
  padding: 8px;
  cursor: pointer;
  background: #fff;
  font-size: 20px;

  &:hover {
    color: hsl(213, 80%, 40%);
  }
`;
const Panel = styled.div `
  border-top: 1px solid ${SelectedTabColor};
  background: ${SelectedTabColor};
  height: ${({ $height }) => $height}px;
  display: flex;
  flex-direction: column;
`;
