import { css } from "@emotion/react";
import styled from "@emotion/styled";
import { motion } from "framer-motion";
import { observer } from "mobx-react-lite";
import React, { useCallback, useEffect, useState } from "react";
export const Error = observer(({ state }) => {
    const [expanded, setExpanded] = useState(false);
    useEffect(() => {
        var _a;
        if (!((_a = state.error) === null || _a === void 0 ? void 0 : _a.details)) {
            setExpanded(false);
        }
    }, [state.error, setExpanded]);
    const onToggle = useCallback(() => {
        var _a;
        if (!((_a = state.error) === null || _a === void 0 ? void 0 : _a.details)) {
            return;
        }
        setExpanded(!expanded);
    }, [state.error, expanded, setExpanded]);
    if (!state.error) {
        return null;
    }
    return (React.createElement(React.Fragment, null,
        React.createElement(ErrorTitle, { animate: {
                y: 0,
            }, initial: {
                y: 100,
            }, transition: {
                delay: 1,
                type: "tween",
            }, "$expandable": !!state.error.details, onClick: onToggle }, state.error.title),
        expanded && React.createElement(ErrorDetails, null, state.error.details)));
});
const ErrorBase = styled(motion.pre) `
  background: hsl(0, 50%, 80%);
  color: hsl(0, 80%, 20%);
  padding: 8px;
  margin: 0;
`;
const ErrorTitle = styled(ErrorBase) `
  font-weight: 600;
  ${({ $expandable }) => $expandable &&
    css `
      cursor: pointer;
    `}
`;
const ErrorDetails = styled(ErrorBase) `
  max-height: 400px;
  overflow-x: hidden;
  overflow-y: auto;
`;
