import { PreviewUpdate } from "@previewjs/core/controller";
import { makeAutoObservable } from "mobx";
import React from "react";

export class ErrorState {
  error: {
    title: string;
    details?: React.ReactNode;
  } | null = null;

  constructor() {
    makeAutoObservable(this);
  }

  update(event: PreviewUpdate) {
    const viteError = event.viteError;
    if (viteError) {
      this.error = {
        title: viteError.err.message,
        details: (
          <>
            {viteError.err.loc?.file && (
              <b>{`Error in ${viteError.err.loc.file}:${viteError.err.loc.line}:${viteError.err.loc.column}\n\n`}</b>
            )}
            {viteError.err.message}
            {viteError.err.stack && `\n${viteError.err.stack}`}
          </>
        ),
      };
    } else if (event.rendering?.kind === "error") {
      const message = event.rendering.error;
      const [title, ...rest] = message.split("\n");
      this.error = {
        title: title || "An unknown error has occurred",
        details: rest.length > 0 && rest.join("\n"),
      };
    } else {
      this.error = null;
    }
  }
}
